@@ -24,14 +24,7 @@ sub init_digests
 
 	# initialize a SHA-256 Digest
 	$self->{header_digest} = new Digest::SHA(256);
-	if ($self->{draft_version} eq "01")
-	{
-		$self->{body_digest} = new Digest::SHA(256);
-	}
-	else
-	{
-		$self->{body_digest} = $self->{header_digest};
-	}
+	$self->{body_digest} = new Digest::SHA(256);
 }
 
 sub sign
@@ -60,26 +53,9 @@ sub verify
 	return $self->check_body_hash;
 }
 
+sub wants_pre_signature_headers
+{
+	return 1;
+}
+
 1;
-
-__END__
-
-=head1 NAME
-
-Mail::DKIM::Algorithm::rsa_sha256 - implements the rsa-sha256 signing algorithm for DKIM
-
-=head1 CONSTRUCTOR
-
-=head2 new() - create an object for the DKIM signing algorithm "rsa-sha256"
-
-  my $algorithm = new Mail::DKIM::Algorithm::rsa_sha256(
-                      Signature => $dkim_signature
-                  );
-
-=head1 METHODS
-
-See Mail::DKIM::Algorithm::Base for the full list of methods supported
-by this algorithm class.
-
-=cut
-
